/***************************************************************************
 *   Copyright (C) 2003 by Hideki Ikemoto                                  *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#include "kitaconfig.h"

KitaConfig* KitaConfig::instance = 0;

KitaConfig* KitaConfig::getInstance()
{
  if(!instance) {
    instance = new KitaConfig();
  }
  return instance;
}

KitaConfig::KitaConfig()
  : m_threadColor( "black" ), m_threadBackgroundColor( "white" ),
    m_popupColor( "black" ), m_popupBackgroundColor( "yellow" )
{
}

KitaConfig::~KitaConfig()
{
}
